/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
/******************************************************************************/
/*  Communication with an EEPROM (e.g. 2465) via I2C bus                      */
/*  The I2C module of the MSP430F2274 is used to communicate with the EEPROM. */
/*  The "Byte Write", "Page Write", "Current Address Read", "Random Read",    */
/*  "Sequential Read" and "Acknowledge Polling" commands or the EEPROM are    */
/*  realized.                                                                 */
/*                                                                            */
/*  developed with IAR Embedded Workbench V5.20.1                             */
/*                                                                            */
/*  Texas Instruments                                                         */
/*  William Goh                                                               */
/*  March 2011                                                                */
/*----------------------------------------------------------------------------*/
/*  updates                                                                   */
/*    Jan 2005:                                                               */
/*        - updated initialization sequence                                   */
/*    March 2009:                                                             */
/*        - updated code for 2xx USCI module                                  */
/*        - added Page Write and Sequential Read functions                    */
/*    March 2011:                                                             */
/*        - Fixed Random and Sequential Reads to Restart                      */
/*        - Added Page Write to support greater than 256 bytes                */


#include <stdint.h>

#define I2C_PORT_SEL    P1SEL1
#define I2C_PORT_OUT    P1OUT
#define I2C_PORT_REN    P1REN
#define I2C_PORT_DIR    P1DIR
#define WP_PORT_DIR     P1DIR
#define WP_PORT_OUT     P1OUT
#define SDA_PIN         BIT6                // UCB0SDA pin
#define SCL_PIN         BIT7                // UCB0SCL pin
#define WP_PIN          BIT5

// 400kHz
#define SCL_CLOCK_DIV_400k   19             // SCL clock devider

// 100kHz
#define SCL_CLOCK_DIV_100k   80             // SCL clock devider

#if (EEPROM_ADDRESS_BYTE_SIZE == 2)
void EEPROM_ByteWrite(uint16_t Address,
                      uint8_t Data);
void EEPROM_PageWrite(uint16_t StartAddress,
                      uint8_t * Data,
                      uint16_t Size);
unsigned char EEPROM_RandomRead(uint16_t Address);
unsigned char EEPROM_CurrentAddressRead(void);
void EEPROM_SequentialRead(uint16_t Address,
                           uint8_t * Data,
                           uint16_t Size);
void EEPROM_AckPolling(void);
#elif (EEPROM_ADDRESS_BYTE_SIZE == 3)
void EEPROM_ByteWrite(uint32_t Address,
                      uint8_t Data);
void EEPROM_PageWrite(uint32_t StartAddress,
                      uint8_t * Data,
                      uint16_t Size);
unsigned char EEPROM_RandomRead(uint32_t Address);
unsigned char EEPROM_CurrentAddressRead(void);
void EEPROM_SequentialRead(uint32_t Address,
                           uint8_t * Data,
                           uint16_t Size);
#endif
void InitI2C(uint8_t eeprom_i2c_address,
             uint8_t eeprom_i2c_speed);
void EEPROM_AckPolling(void);

void SENSOR_getData(unsigned char Address,
                    unsigned char * Data,
                    unsigned int Size);

#define  ENABLE_WRITE_PROTECT   WP_PORT_OUT |= WP_PIN;
#define  DISABLE_WRITE_PROTECT  WP_PORT_OUT &= ~WP_PIN;

// Header packet definitions from Master as to which data we should
// send back
#define SENSOR_HEADER_VCC       0x01
#define SENSOR_HEADER_TEMP_C    0x02
#define SENSOR_HEADER_TEMP_F    0x03
