/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

#include <stdint.h>

#define SPI_SCLK_PORT           GPIO_PORT_P2
#define SPI_SCLK_PIN            GPIO_PIN2   // UCB0SCLK pin (P2.2)
#define SPI_MOSI_MISO_PORT      GPIO_PORT_P1
#define SPI_MOSI_MISO_PIN       (GPIO_PIN6 | GPIO_PIN7)  // UCB0MOSI pin (P1.6)
// and UCB0MISO pin (1.7)
#define SPI_CSn_PORT            GPIO_PORT_P1
#define SPI_CSn_PIN             GPIO_PIN4   // Chip Select pin (P1.4)
#define WP_PORT                 GPIO_PORT_P1
#define WP_PIN                  GPIO_PIN5   // Write Protect pin (P1.5)

// If defined as SPI basee address
#define EEPROM_SPI_EUSCI_BASE       EUSCI_B0_BASE

#define __SYSTEM_CLOCK__        8000000
#define SPI_SCLK_CLOCK_250k     250000      // 250 kbps
#define SPI_SCLK_CLOCK_300k     300000      // 300 kbps
#define SPI_SCLK_CLOCK_500k     500000      // 500 kbps
#define SPI_SCLK_CLOCK_1M       1000000     // 1 Mbps
#define SPI_SCLK_CLOCK_2M       2000000     // 2 Mbps

#define EEPROM_WRITE_OPCODE     0x02
#define EEPROM_READ_OPCODE      0x03
#define SENSOR_READ_OPCODE      0x10

#if (EEPROM_ADDRESS_BYTE_SIZE == 2)
void EEPROM_ByteWrite(uint16_t Address,
                      uint8_t Data);
void EEPROM_PageWrite(uint16_t StartAddress,
                      uint8_t * Data,
                      uint16_t Size);
unsigned char EEPROM_RandomRead(uint16_t Address);
unsigned char EEPROM_CurrentAddressRead(void);
void EEPROM_SequentialRead(uint16_t Address,
                           uint8_t * Data,
                           uint16_t Size);
void EEPROM_AckPolling(void);
#elif (EEPROM_ADDRESS_BYTE_SIZE == 3)
void EEPROM_ByteWrite(uint32_t Address,
                      uint8_t Data);
void EEPROM_PageWrite(uint32_t Address,
                      uint8_t * Data,
                      uint16_t Size);
unsigned char EEPROM_RandomRead(uint32_t Address);
unsigned char EEPROM_CurrentAddressRead(void);
void EEPROM_SequentialRead(uint32_t Address,
                           uint8_t * Data,
                           uint16_t Size);
#endif
void SPI_Init(uint32_t eeprom_spi_speed);
void EEPROM_AckPolling(void);

void SENSOR_getData(unsigned char Address,
                    unsigned char * Data,
                    unsigned int Size);

#define  ENABLE_WRITE_PROTECT   GPIO_setOutputHighOnPin(WP_PORT, WP_PIN);
#define  DISABLE_WRITE_PROTECT  GPIO_setOutputLowOnPin(WP_PORT, WP_PIN);

// Header packet definitions from Master as to which data we should
// send back
#define SENSOR_HEADER_VCC       0x01
#define SENSOR_HEADER_TEMP_C    0x02
#define SENSOR_HEADER_TEMP_F    0x03
