/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
#ifndef EEPROM_DEFINITIONS_H_
#define EEPROM_DEFINITIONS_H_

#include "eeprom_i2c.h"

// Used mainly to debug the EEPROM code
//#define     DEBUG_EEPROM

// Define this as a I2C or SPI interface project
#define     INTERFACE_I2C

// Set the address byte size
// For EEPROM memory less than 64kb, use 2 byte addressing
//#define     EEPROM_ADDRESS_BYTE_SIZE   2
// For EEPROM memory greater than 64kb, use 3 byte addressing
#define     EEPROM_ADDRESS_BYTE_SIZE   3

// Define the Slave address for I2C and SPI mode
#define EEPROM_MEMORY_SLAVE_ADDRESS    0x50
#define EEPROM_COPRO_SLAVE_ADDRESS     0x51

// If defined as SPI base address
#define EEPROM_I2C_EUSCI_BASE       EUSCI_B1_BASE
#define USCI_xx_VECTOR              USCI_B1_VECTOR

// EEPROM size is manually calculated for performance reasons
// The lower boundary memory is defined by the customer on where it should
// start. In this example, the application code resides from 0x4400 to 0x6BFF
// and EEPROM starts from 0x6C00 to 0x44000 where 0xFF80 to 0xFFFF is reserved.

// Define EEPROM size 1 which is the lower boundary memory.
// This example starts from 0x6C00 as the lower 10k memory is reserved for
// application space.
#define EEPROM1_BEGIN       0x6c00
#define EEPROM1_END         0xFF80
#define EEPROM1_SIZE        (EEPROM1_END - EEPROM1_BEGIN)
#define EEPROM1_LONG_SIZE   (EEPROM1_SIZE / 4)
// Define EEPROM size 2 which is the upper boundary memory.
#define EEPROM2_BEGIN       0x10000
#define EEPROM2_END         0x44000
#define EEPROM2_SIZE        (EEPROM2_END - EEPROM2_BEGIN)
#define EEPROM2_LONG_SIZE   (EEPROM2_SIZE / 4)

#define EEPROM_SLAVE_SDA_SCL_PORT  GPIO_PORT_P5
#define EEPROM_SLAVE_SDA_PIN   GPIO_PIN0
#define EEPROM_SLAVE_SCL_PIN   GPIO_PIN1

// Define where Write Protect pin is located.
// Currently set to P8.3 on MSP-EXP430FR5994
#define WP_PORT         GPIO_PORT_P8
#define WP_IES          P8IES
#define WP_BIT          BIT3

// External define variables
extern void * eeprom1_start_address;
extern uint8_t * eeprom1_end_address;
extern void * eeprom2_start_address;
extern uint32_t eeprom_total_size;
extern uint8_t * eeprom2_end_address;

extern volatile uint32_t eepromReadIndexPointer;
extern volatile uint32_t eepromWriteIndexPointer;
extern uint8_t * eepromReadDataPointerAddress;
extern uint8_t * eepromWriteDataPointerAddress;

extern float currentVcc;
extern uint8_t currentVccArray[sizeof(float)];
extern float currentTemperatureDegC;
extern uint8_t currentTemperatureDegCArray[sizeof(float)];
extern float currentTemperatureDegF;
extern uint8_t currentTemperatureDegFArray[sizeof(float)];

#endif
