/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
#ifndef EEPROM_DEFINITIONS_H_
#define EEPROM_DEFINITIONS_H_

#include "eeprom_spi.h"

// Used mainly to debug the EEPROM code
//#define     DEBUG_EEPROM

// Define this as a I2C or SPI interface project
#define     INTERFACE_SPI

// Set the address byte size
// For EEPROM memory less than 64kb, use 2 byte addressing
#define     EEPROM_ADDRESS_BYTE_SIZE   2

// Define the Slave address for I2C and SPI mode
#define EEPROM_MEMORY_SLAVE_ADDRESS    0x50
#define EEPROM_COPRO_SLAVE_ADDRESS     0x51

// If defined as SPI base address
#define EEPROM_SPI_EUSCI_BASE       EUSCI_B0_BASE
#define USCI_xx_VECTOR              USCI_B0_VECTOR

// Define if DMA is used. DMA is only valid for SPI mode.
//#define USE_DMA

// EEPROM size is manually calculated for performance reasons
// The lower boundary memory is defined by the customer on where it should
// start. In this example, the application code resides from 0xC400 to 0xDBFF
// and EEPROM starts from 0xDC00 to 0xFF80 is reserved.

// Define EEPROM size 1 which is the lower boundary memory.
// This example starts from 0x6C00 as the lower 10k memory is reserved for
// application space.
#define EEPROM1_BEGIN       0xdc00
#define EEPROM1_END         0xFF80
#define EEPROM1_SIZE        (EEPROM1_END - EEPROM1_BEGIN)
#define EEPROM1_LONG_SIZE   (EEPROM1_SIZE / 4)

#define EEPROM_SLAVE_SCLK_PORT  GPIO_PORT_P5
#define EEPROM_SLAVE_MOSI_MISO_PORT   GPIO_PORT_P5
#define EEPROM_SLAVE_SCLK_PIN   GPIO_PIN1
#define EEPROM_SLAVE_MISO_PIN   GPIO_PIN3
#define EEPROM_SLAVE_MOSI_PIN   GPIO_PIN2

// Define which GPIO interrupt ports are used for CS and WP interrupts
// MSP-EXP430FR4133 uses Port1
#define PORTX_VECTOR            PORT1_VECTOR
#define PORT_IV_REG             P1IV

// Define CSn pin on P1.4 on MSP-EXP430FR4133
#define EEPROM_SLAVE_CSn_PORT   GPIO_PORT_P1
#define EEPROM_SLAVE_CSn_IES    P1IES
#define EEPROM_SLAVE_CSn_PIN    GPIO_PIN4

// Define where Write Protect pin is located.
// Currently set to P1.3 on MSP-EXP430FR4133
#define WP_PORT                 GPIO_PORT_P1
#define WP_IES                  P1IES
#define WP_BIT                  BIT3

// External define variables
extern void * eeprom1_start_address;
extern uint8_t * eeprom1_end_address;
#ifdef EEPROM2_SIZE
extern void * eeprom2_start_address;
extern uint8_t * eeprom2_end_address;
#endif
extern uint32_t eeprom_total_size;

extern volatile uint32_t eepromReadIndexPointer;
extern volatile uint32_t eepromWriteIndexPointer;
extern uint8_t * eepromReadDataPointerAddress;
extern uint8_t * eepromWriteDataPointerAddress;

extern float currentVcc;
extern uint8_t currentVccArray[sizeof(float)];
extern float currentTemperatureDegC;
extern uint8_t currentTemperatureDegCArray[sizeof(float)];
extern float currentTemperatureDegF;
extern uint8_t currentTemperatureDegFArray[sizeof(float)];

#endif
