/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
#ifndef EEPROM_I2C_H_
#define EEPROM_I2C_H_

#define OPCODE_READ     0x03
#define OPCODE_WRITE    0x02
#define OPCODE_SENSOR   0x10

//Definitions for a generic PxIV table
#define PxIV_NONE           (0x0000u)    /* No Interrupt pending */
#define PxIV_PxIFG0         (0x0002u)    /* PxV PxIFG.0 */
#define PxIV_PxIFG1         (0x0004u)    /* PxIV PxIFG.1 */
#define PxIV_PxIFG2         (0x0006u)    /* PxIV PxIFG.2 */
#define PxIV_PxIFG3         (0x0008u)    /* PxIV PxIFG.3 */
#define PxIV_PxIFG4         (0x000Au)    /* PxIV PxIFG.4 */
#define PxIV_PxIFG5         (0x000Cu)    /* PxIV PxIFG.5 */
#define PxIV_PxIFG6         (0x000Eu)    /* PxIV PxIFG.6 */
#define PxIV_PxIFG7         (0x0010u)    /* PxIV PxIFG.7 */

extern uint8_t spiOpCode;

//******************************************************************************
//
//! \brief  Initializes the SPI interface as Slave mode.
//!
//! This API initializes the SPI interface communication in slave mode for
//! EEPROM communication. The user can select any interface available on the
//! MSP430.
//!
//! \param  none
//!
//! \return none
//
//******************************************************************************
void eeprom_init_SpiInterface(void);

//******************************************************************************
//
//! \brief  Re-Initializes the SPI module to start receiving again
//!
//! This API is mainly used to generate a NACK while the device is still busy
//! writing to FRAM memory during EEPROM operation.
//!
//! \param  none
//!
//! \return none
//
//******************************************************************************
void eeprom_reEnableSpi(void);

//******************************************************************************
//
//! \brief  Disables the SPI module by putting it into reset mode
//!
//! This API is mainly used to generate a NACK while the device is still busy
//! writing to FRAM memory during EEPROM operation.
//!
//! \param  none
//!
//! \return none
//
//******************************************************************************
void eeprom_disableSpi(void);

#endif
